%global srcname wikitcms

# Python 3 only for Fedora for now.
%if 0%{?fedora} > 12
%global with_python3 1
%endif

Name:           python-%{srcname}
Version:        2.1.6
Release:        2%{?dist}
Summary:        Fedora QA wiki test management Python library

Group:          System Environment/Libraries
License:        GPLv3+
URL:            https://www.happyassassin.net/wikitcms
Source0:        https://www.happyassassin.net/wikitcms/releases/%{srcname}-%{version}.tar.xz
BuildArch:      noarch
BuildRequires:  python2-devel
BuildRequires:  python-setuptools
# For tests
# No python2-pytest on EL or F22
BuildRequires:  pytest
# No python2-mock on EL or F22
BuildRequires:  python-mock
BuildRequires:  python2-mwclient >= 0.7.2
BuildRequires:  python2-fedfind >= 2.3.0
BuildRequires:  python2-cached_property
BuildRequires:  python-six
%if 0%{?with_python3}
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
# For tests
BuildRequires:  python3-pytest
BuildRequires:  python3-mock
BuildRequires:  python3-mwclient >= 0.8.0-2
BuildRequires:  python3-fedfind >= 2.3.0
BuildRequires:  python3-cached_property
BuildRequires:  python3-six
%endif # with_python3

%description
python-wikitcms is a library for interacting with Fedora's wiki-based 'test
management' system. It can:

* Create the pages for release validation test events
* Find existing release validation event pages, in various ways
* Report test results

The wiki-based test management system itself is documented at:
https://fedoraproject.org/wiki/Wikitcms

%package -n python2-%{srcname}
Summary:        %{summary}
%{?python_provide:%python_provide python2-%{srcname}}
Requires:       python2-mwclient >= 0.7.2
Requires:       python2-fedfind >= 2.3.0
Requires:       python2-cached_property
# FIXME: python-six for F22 does not provide python2-six
Requires:       python-six

%description -n python2-%{srcname}
python-wikitcms is a library for interacting with Fedora's wiki-based 'test
management' system. It can:

* Create the pages for release validation test events
* Find existing release validation event pages, in various ways
* Report test results

The wiki-based test management system itself is documented at:
https://fedoraproject.org/wiki/Wikitcms

This is the Python 2 build.

%if 0%{?with_python3}
%package -n python3-%{srcname}
Summary:        %{summary}
%{?python_provide:%python_provide python3-%{srcname}}
Requires:       python3-mwclient >= 0.8.0-2
Requires:       python3-fedfind >= 2.3.0
Requires:       python3-cached_property
Requires:       python3-six

%description -n python3-%{srcname}
python-wikitcms is a library for interacting with Fedora's wiki-based 'test
management' system. It can:

* Create the pages for release validation test events
* Find existing release validation event pages, in various ways
* Report test results

The wiki-based test management system itself is documented at:
https://fedoraproject.org/wiki/Wikitcms

This is the Python 3 build.
%endif # if with_python3

%prep
%autosetup -n %{srcname}-%{version}

%build
%py2_build
%if 0%{?with_python3}
%py3_build
%endif # if with_python3

%install
%py2_install
%if 0%{?with_python3}
%py3_install
%endif # if with_python3

%check
%{__python2} setup.py test

%if 0%{?with_python3}
%{__python3} setup.py test
%endif # with_python3

%files -n python2-%{srcname}
%license COPYING
%doc README.md
%{python2_sitelib}/%{srcname}*

%if 0%{?with_python3}
%files -n python3-%{srcname}
%license COPYING
%doc README.md
%{python3_sitelib}/%{srcname}*
%endif # if with_python3

%changelog
* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.6-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Wed Apr 20 2016 Adam Williamson <awilliam@redhat.com> - 2.1.6-1
- new release 2.1.6 (re-add 'end' to TcmsPageList and generators)

* Fri Apr 08 2016 Adam Williamson <awilliam@redhat.com> - 2.1.5-1
- new release 2.1.5 (fix an issue with result row identification)

* Wed Mar 23 2016 Adam Williamson <awilliam@redhat.com> - 2.1.4-1
- new release 2.1.4 (drop a no-longer-needed workaround)
- enable tests

* Thu Mar 17 2016 Adam Williamson <awilliam@redhat.com> - 2.1.3-1
- new release 2.1.3 (adjust to fedfind / productmd changes)

* Wed Mar 16 2016 Adam Williamson <awilliam@redhat.com> - 2.1.2-1
- new release 2.1.2 (couple of bug fixes)

* Wed Mar 16 2016 Adam Williamson <awilliam@redhat.com> - 2.1.0-1
- new release 2.1.0 (more major Pungi 4-related changes)

* Fri Mar 04 2016 Adam Williamson <awilliam@redhat.com> - 2.0.2-1
- new release 2.0.2 (add a system-wide credentials file)

* Thu Mar 03 2016 Adam Williamson <awilliam@redhat.com> - 2.0.0-1
- new release 2.0.0
- Python 3 support added, python2-wikitcms / python3-wikitcms split

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.13.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Dec 24 2015 Adam Williamson <awilliam@redhat.com> - 1.13.3-1
- new release 1.13.3: fix reporting results for similarly-named tests

* Tue Oct 27 2015 Adam Williamson <awilliam@redhat.com> - 1.13.2-1
- new release 1.13.2: fix triplet_sort when release is an int (relval)

* Mon Oct 26 2015 Adam Williamson <awilliam@redhat.com> - 1.13.1-1
- new release 1.13.1: another sorting fix

* Tue Oct 20 2015 Adam Williamson <awilliam@redhat.com> - 1.13-1
- new release 1.13: sorting improvements

* Sat Sep 19 2015 Adam Williamson <awilliam@redhat.com> - 1.12.3-1
- new release 1.12.3: use fedfind 'shortdesc' for download table
- requires fedfind >= 1.6 for shortdesc

* Thu Sep 17 2015 Adam Williamson <awilliam@redhat.com> - 1.12.2-1
- new release 1.12.2: drop a stray debug print, better wiki download tables
- Provides: python2-wikitcms
- requires fedfind >= 1.5.1 for the download table improvements

* Fri Aug 28 2015 Adam Williamson <awilliam@redhat.com> - 1.12.1-1
- new release 1.12.1: fix mwclient deprecation warning, minor updates

* Tue Jun 30 2015 Adam Williamson <awilliam@redhat.com> - 1.12-1
- new release 1.12: various bits added for Test Day handling

* Tue Apr 21 2015 Adam Williamson <awilliam@redhat.com> - 1.11.4-1
- new release 1.11.4: handling of 'bot' results (from automated test systems)

* Fri Apr 17 2015 Adam Williamson <awilliam@redhat.com> - 1.11.3-1
- new release 1.11.3: use system cached_property

* Thu Mar 26 2015 Adam Williamson <awilliam@redhat.com> - 1.11.2-1
- new release 1.11.2: bugfix (reporting multiple results to one row)

* Wed Mar 25 2015 Adam Williamson <awilliam@redhat.com> - 1.11.1-1
- new release 1.11.1: bugfix (affected relval size-check release guessing)

* Wed Mar 25 2015 Adam Williamson <awilliam@redhat.com> - 1.11-1
- new release 1.11: much more powerful result submission
- update description a bit

* Mon Mar 16 2015 Adam Williamson <awilliam@redhat.com> - 1.10.3-1
- new release 1.10.3: drop some unnecessary case normalization

* Wed Feb 18 2015 Adam Williamson <awilliam@redhat.com> - 1.10.2-1
- fix processing of Branched nightly pages

* Wed Feb 18 2015 Adam Williamson <awilliam@redhat.com> - 1.10.1-1
- revisions to event versioning, new get_validation_foo() methods, bugfixes

* Thu Feb 12 2015 Adam Williamson <awilliam@redhat.com> - 1.9.1-1
- new release 1.9.1: don't include a stray copy of fedfind

* Thu Feb 12 2015 Adam Williamson <awilliam@redhat.com> - 1.9-1
- new release 1.9: Download page creation, cleanups

* Wed Jan 07 2015 Adam Williamson <awilliam@redhat.com> - 1.8.4-1
- new release 1.8.4: fix page creation when no 'oldtext'

* Fri Jan 02 2015 Adam Williamson <awilliam@redhat.com> - 1.8.3-1
- new release 1.8.3: drop sanitization stuff (moved to relval), fix a bug

* Thu Jan 01 2015 Adam Williamson <awilliam@redhat.com> - 1.8.2-1
- new release 1.8.2: slightly stronger fix for last bug

* Thu Jan 01 2015 Adam Williamson <awilliam@redhat.com> - 1.8.1-1
- new release 1.8.1: serious security issue

* Tue Dec 23 2014 Adam Williamson <awilliam@redhat.com> - 1.8-1
- new release 1.8: multiple fixes and enhancements

* Fri Dec 19 2014 Adam Williamson <awilliam@redhat.com> - 1.7-1
- new release 1.7 (major overhaul)

* Tue Dec 16 2014 Adam Williamson <awilliam@redhat.com> - 1.6.1-1
- new release 1.6.1: revised nightly handling, bugfixes

* Tue Dec 09 2014 Adam Williamson <awilliam@redhat.com> - 1.5-1
- new release: nightly compose support

* Fri Oct 31 2014 Adam Williamson <awilliam@redhat.com> - 1.4.1-1
- new release (only enforces mwclient 0.7 dependency)

* Sat Oct 25 2014 Adam Williamson <awilliam@redhat.com> - 1.4-1
- new release 1.4 (API breaks all over)

* Fri Oct 24 2014 Adam Williamson <awilliam@redhat.com> - 1.3.1-1
- new release 1.3.1 (minor update)

* Tue Oct 21 2014 Adam Williamson <awilliam@redhat.com> - 1.3-1
- new release

* Thu Oct 16 2014 Adam Williamson <awilliam@redhat.com> - 1.2-1
- new release 1.2

* Mon Oct 13 2014 Adam Williamson <awilliam@redhat.com> - 1.1-1
- new release 1.1

* Mon Oct 06 2014 Adam Williamson <awilliam@redhat.com> - 1.0-1
- first build
